.. include:: ../../README.rst


Contents
--------

.. toctree::
   :maxdepth: 2

   basic
   advanced
   social
   narrative
   customise
   api
   changelog

Python 3
--------

Python 3 support is limited to python 3.3 and 3.4.
Unfortunately, python 3.x support does not include social authentication.



License
-------

Copyright (c) 2014 by pyramid_fullauth authors and contributors. See :ref:`authors`

This module is part of pyramid_fullauth and is released under
the MIT License (MIT): http://opensource.org/licenses/MIT
